@@ -122,12 +122,6 @@ class SqueakAdminServerServicer(squeak_admin_pb2_grpc.SqueakAdminServicer):
     def SetSqueakProfileFollowing(self, request, context):
         return self.handler.handle_set_squeak_profile_following(request)
 
-    def SetSqueakProfileUseCustomPrice(self, request, context):
-        return self.handler.handle_set_squeak_profile_use_custom_price(request)
-
-    def SetSqueakProfileCustomPrice(self, request, context):
-        return self.handler.handle_set_squeak_profile_custom_price(request)
-
     def RenameSqueakProfile(self, request, context):
         return self.handler.handle_rename_squeak_profile(request)
 
